Description Usage Arguments Value
View source: R/calculate_measures.R
Calculate Summary Measures from Raw Accelerometer Data
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 | calculate_measures(
df,
epoch = "1 min",
fix_zeros = TRUE,
fill_in = TRUE,
dynamic_range = c(-6, 6),
calculate_mims = TRUE,
verbose = TRUE,
...
)
calculate_ai(df, epoch = "1 min")
calculate_n_idle(df, epoch = "1 min")
calculate_mad(df, epoch = "1 min")
calculate_mims(df, epoch = "1 min", dynamic_range = c(-6, 6), ...)
|
df |
An object with columns 'X', 'Y', and 'Z' or an object of class 'AccData' |
epoch |
length of time to calculate measures over. a character string
specifying a time unit or a multiple of a unit to be rounded to.
Valid base units are 'second', 'minute', 'hour', 'day', 'week', 'month',
'bimonth', 'quarter', 'season', 'halfyear', and 'year'.
Arbitrary unique English abbreviations as in the |
fix_zeros |
Should |
fill_in |
if |
dynamic_range |
Dynamic range of the device, in gravity units |
calculate_mims |
Should MIMS units be calculated? |
verbose |
print diagnostic messages |
... |
additional arguments to pass to |
A data set with the calculated features
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.